@@ -20,13 +20,15 @@ BLOWFISH_DIR = os.path.join(os.path.dirname(__file__), "_csrc")
 
 ffi = FFI()
 
-ffi.cdef("""
+ffi.cdef(
+    """
 int bcrypt_hashpass(const char *, const char *, char *, size_t);
 int encode_base64(char *, const uint8_t *, size_t);
 int bcrypt_pbkdf(const char *, size_t, const uint8_t *, size_t,
                  uint8_t *, size_t, unsigned int);
 int timingsafe_bcmp(const void *, const void *, size_t);
-""")
+"""
+)
 
 ffi.set_source(
     "_bcrypt",
